/*
 * $Header: /home/cvspublic/jakarta-commons-sandbox/resources/src/java/org/apache/commons/resources/ResourcesFactory.java,v 1.5 2002/12/28 04:40:55 craigmcc Exp $
 * $Revision: 1.5 $
 * $Date: 2002/12/28 04:40:55 $
 *
 * ====================================================================
 *
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution, if
 *    any, must include the following acknowlegement:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowlegement may appear in the software itself,
 *    if and wherever such third-party acknowlegements normally appear.
 *
 * 4. The names "The Jakarta Project", "Commons", and "Apache Software
 *    Foundation" must not be used to endorse or promote products derived
 *    from this software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache"
 *    nor may "Apache" appear in their names without prior written
 *    permission of the Apache Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */


package org.apache.commons.resources;


import java.io.Serializable;


/**
 * <a>A {@link ResourcesFactory} is a factory pattern interface for a
 * class that can create {@link Resources} instances based on a logical
 * name that is passed to the factory.  Repeated requests to return a
 * {@link Resources} instance with the same name should return the same
 * {@link Resources} instance each time.</p>
 *
 * <p>Implementations of {@link ResourcesFactory} <strong>MUST</strong>
 * include a zero-arguments constructor so that instances of the factory
 * can be dynamically created.  Therefore, configuration information
 * above and beyond the configuration String will generally be specified
 * via JavaBeans property setters o the {@link ResourcesFactory}
 * implementation class.</p>
 *
 * @author Mike Schachter (mschachter@hp.com)
 * @author Craig R. McClanahan
 * @version $Revision: 1.5 $ $Date: 2002/12/28 04:40:55 $
 */

public interface ResourcesFactory extends Serializable {
    

    // ------------------------------------------------------------- Properties


    /**
     * <p>Return the <code>returnNull</code> property value that will be
     * configured on {@link Resources} instances created by this factory.</p>
     */
    public boolean isReturnNull();


    /**
     * <p>Set the <code>returnNull</code> property value that will be
     * configured on {@link Resources} instances created by this factory.</p>
     *
     * @param returnNull The new value to delegate
     */
    public void setReturnNull(boolean returnNull);


    // --------------------------------------------------------- Public Methods


    /**
     * <p>Create (if necessary) and return a {@link Resources} instance
     * for the specified logical name, with a default configuration.</p>
     *
     * @param name Logical name of the {@link Resources} instance to
     *  be returned
     *
     * @exception ResourcesException if a {@link Resources} instance
     *  of the specified logical name cannot be returned.
     */
    public Resources getResources(String name)
        throws ResourcesException;


    /**
     * <p>Create (if necessary) and return a {@link Resources} instance
     * for the specified logical name, with a configuration based on
     * the specified configuration String.</p>
     *
     * @param name Logical name of the {@link Resources} instance to
     *  be returned
     * @param config Configuration string for this resource (meaning
     *  is dependent upon the {@link ResourcesFactory} implementation
     *  being utilized), or <code>null</code> for the default
     *  configuration
     *
     * @exception ResourcesException if a {@link Resources} instance
     *  of the specified logical name cannot be returned.
     */
    public Resources getResources(String name, String config)
        throws ResourcesException;


    /**
     * <p>Release any internal references to {@link Resources} instances
     * that have been returned previously, after calling the
     * <code>destroy()</code> method of each such instance.</p>
     *
     * @exception ResourcesException if an error occurs while releasing
     */
    public void release() throws ResourcesException;


}
