/*
 * $Header: /home/cvspublic/jakarta-commons-sandbox/resources/src/java/org/apache/commons/resources/impl/WebappXMLResourcesFactory.java,v 1.3 2003/07/21 04:57:22 craigmcc Exp $
 * $Revision: 1.3 $
 * $Date: 2003/07/21 04:57:22 $
 *
 * ====================================================================
 *
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution, if
 *    any, must include the following acknowlegement:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowlegement may appear in the software itself,
 *    if and wherever such third-party acknowlegements normally appear.
 *
 * 4. The names "The Jakarta Project", "Commons", and "Apache Software
 *    Foundation" must not be used to endorse or promote products derived
 *    from this software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache"
 *    nor may "Apache" appear in their names without prior written
 *    permission of the Apache Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */


package org.apache.commons.resources.impl;


import javax.servlet.ServletContext;

import org.apache.commons.resources.Resources;
import org.apache.commons.resources.ResourcesException;
import org.apache.commons.resources.ResourcesFactory;


/**
 * <p>Concrete implementation of {@link ResourcesFactory} that creates
 * {@link Resources} instances that wrap a family (one per Locale) of
 * XML documents that share a base context-relative path for
 * servlet context resources, and have name suffixes reflecting
 * the Locale for which the document's messages apply.  Resources are
 * looked up in a hierarchy of documents in a manner identical to that
 * performed by <code>java.util.ResourceBundle.getBundle()</code>.</p>
 *
 * <p>The configuration variable passed to the <code>createResources()</code>
 * method must be the context-relative base name of the XML document family,
 * and must begin with a slash ('/') character.
 * For example, if the configuration URL is passed as
 * <code>/WEB-INF/resources/MyResources</code>, the resources for the
 * <code>en_US</code> Locale would be stored under context resource
 * <code>/WEB-INF/resources/MyReesources_en_US.xml</code>, and the default
 * resources would be stored in
 * <code>/WEB-INF/resources/MyResources.xml</code>.</p>
 *
 * @author Craig R. McClanahan
 * @version $Revision: 1.3 $ $Date: 2003/07/21 04:57:22 $
 */

public class WebappXMLResourcesFactory extends ResourcesFactoryBase {
    

    // --------------------------------------------------------- Public Methods


    // ------------------------------------------------------------- Properties


    /**
     * <p>The <code>ServletContext</code> instance for resolving
     * our resources references.</p>
     */
    private ServletContext servletContext = null;


    /**
     * <p>Return the <code>ServletContext</code> instance for
     * resolving our resources references.</p>
     */
    public ServletContext getServletContext() {

        return (this.servletContext);

    }


    /**
     * <p>Set the <code>ServletContext</code> instance for
     * resolving our resources references.</p>
     */
    public void setServletContext(ServletContext servletContext) {

        this.servletContext = servletContext;

    }


    // ------------------------------------------------------ Protected Methods


    /**
     * <p>Create and return a new {@link Resources} instance with the
     * specified logical name, after calling its <code>init()</code>
     * method and delegating the relevant properties.</p>
     *
     * @param name Logical name of the {@link Resources} instance to create
     * @param config Configuration string for this resource (if any)
     *
     * @exception ResourcesException if a {@link Resources} instance
     *  of the specified logical name cannot be created.
     */
    protected Resources createResources(String name, String config)
        throws ResourcesException {

        Resources resources =
            new WebappXMLResources(name, config, servletContext);
        resources.setReturnNull(isReturnNull());
        resources.init();
        return (resources);

    }


}
